The GAM Public Chat Room is a place to ask for help, discuss what you are working on or just shoot the breeze. The Room is an experiment as Google Chat is generally not designed for public chat but it's one less account to sign up for. Joining the room requires a few steps.

## Joining the Chat Room
1. To join the GAM Public Chat room, you need to first join a Google Group. You can either:

   - Visit [the group page](https://groups.google.com/a/s.jaylee.us/g/gam-public-chat) and click "Join group" at the top.
   - send an email to [gam-public-chat+subscribe@s.jaylee.us](mailto:gam-public-chat+subscribe@s.jaylee.us). It does not matter what you put for the email subject or body. The group will reply asking if you want to join. Reply to the group message (again, subject and body don't matter). In a few minutes you'll get a welcome message and you will be a member of the group.

2. Once you've joined [the Google Group](https://groups.google.com/a/s.jaylee.us/g/gam-public-chat) you can then join the [GAM Public Chat](https://chat.google.com/room/AAAA4BULhWo) room.

## FAQ

### How do I start a new topic?
The GAM chat room is threaded. At the very bottom of the room you should see a button to start a new thread. Using threads allows other room participants to monitor or ignore topics at will. When in doubt, start a new thread. See [Google's help article](https://support.google.com/chat/answer/7654371) for full details.

### How do I format text when posting a Chat?
Google Chat supports [special markup text](https://support.google.com/chat/answer/7649118). The most useful when discussing GAM commands is the triple backtick (```) surrounding your GAM command. This will put your command in a separate codeblock making it easier for others to read.

### How do I reduce notifications for the room?
Google Chat allows you to manage notifications globally, for each room and for each threaded conversation. See [Google's help article](https://support.google.com/chat/answer/7655718). Being able to ignore one particular back-and-forth thread while still seeing new threads is very useful.

### Should I ask questions in the Chat room or the Google Group?
It's really up to you. The Chat room is meant to decrease response time but it may or may not be a good time for others to respond to you. If you fail to get a response in the Chat room, try the group where it's easier for others to respond in their own time.

### How can I get notifications even when I don't have the Chat tab open in Chrome?
You can [install the standalone app for Chat](https://support.google.com/chat/answer/9455386).
